
%%                                                             COLOURS 2.1

% Produces colour array to subsequently colour multiple graphs etc.

% All at once (using number vector, e.g. iColor = [1 2 3])
% or one at a time (using value, e.g. iColor = 1)

% use:
%   iColor          = [1];
%   colourSuiteName = 'standard';
%   background      = 'light';          %'light' or 'dark'
%   [opColor]       = f_Colours(iColor,colourSuiteName,background)

%                                                Fabio Crameri, 06.04.2017

%% NOTES

function [opColor] = f_Colours(iColor,colourSuiteName,background)

%% DEFAULTS
if isempty(background); background  = 'light'; end

%% COLOUR SUITES
if strcmp(colourSuiteName,'standard')   %goes with light and dark background
    %% 'standard'
    ColorSet = [
        0.5   	0.5 	0.5     % Data 1 - grey
        0       0.4470 	0.7410  % Data 2 - blue
        0.8500	0.3250 	0.0980  % Data 3 - red
        0.9290 	0.6940 	0.1250  % Data 4 - orange
        0.4940 	0.1840 	0.5560  % Data 5 - lila
        0.3010 	0.7450	0.9330  % Data 6 - cyan
        0.6350 	0.0780 	0.1840  % Data 7 - dark red
        0.95    0.45    0.45    % Data 8 - light red
        0.95    0.95    0.00    % Data 9 - yellow
        0.25    0.25    0.75    % Data 10 - dark blue
        0.75    0.75    0.75    % Data 11 - light grey
        0.25    0.25    0.25    % Data 12 - dark grey
        0.76    0.57    0.17    % Data 13 - okker
        0.54    0.63    0.22    % Data 14 - greenish yellow
        0.34    0.57    0.92    % Data 15 - light blue
        1.00    0.10    0.60    % Data 16 - strong pink
        0.88    0.75    0.73    % Data 17 - light pink
        0.10    0.49    0.47    % Data 18 - dark cyan
        0.66    0.34    0.65    % Data 19 - dark lila
        0.99    0.41    0.23    % Data 20 - strong orange
        ];
    
elseif strcmp(colourSuiteName,'C')
    %% 'C'
    if strcmp(background,'light')
        ColorSet = [
            0.0   	0.0 	0.0     % Data 1 - black
            0.3   	0.3 	0.3  	% Data 2 - dark grey
            0.6   	0.6 	0.6     % Data 3 - light grey
            0.25    0.15    0.4     % Data 4 - dark lila
            0.2353	0.349 	0.757   % Data 5 - blue
            0.34    0.57    0.92    % Data 6 - light blue
            0.75 	0.6 	0.85    % Data 7 - light lila
            0.3010 	0.7450	0.9330  % Data 8 - cyan
            0.6667 	0.184 	0.11    % Data 9 - red
            0.9290 	0.6940 	0.1250  % Data 10 - orange
            0.76    0.57    0.17    % Data 11 - okker
            0.95    0.95    0.00    % Data 12 - yellow
            0.95    0.45    0.45    % Data 13 - light red
            0.88    0.75    0.73    % Data 14 - light pink
            0.10    0.49    0.47    % Data 15 - dark cyan
            0.66    0.34    0.65    % Data 16 - dark lila
            0.6350 	0.0780 	0.1840  % Data 17 - dark red
            0.54    0.63    0.22    % Data 18 - greenish yellow
            1.00    0.10    0.60    % Data 19 - strong pink
            0.99    0.41    0.23    % Data 20 - strong orange
            ];
    elseif strcmp(background,'dark')
        ColorSet = [
            1.0   	1.0 	1.0     % Data 1 - white
            0.7   	0.7 	0.7     % Data 2 - light grey
            0.4   	0.4 	0.4  	% Data 3 - dark grey
            0.75 	0.6 	0.85    % Data 4 - light lila
            0.34    0.57    0.92    % Data 5 - light blue
            0.2353	0.349 	0.757   % Data 6 - blue
            0.25    0.15    0.4     % Data 7 - dark lila
            0.3010 	0.7450	0.9330  % Data 8 - cyan
            0.76    0.57    0.17    % Data 9 - okker
            0.95    0.95    0.00    % Data 10 - yellow
            0.9290 	0.6940 	0.1250  % Data 11 - orange
            0.25    0.25    0.75    % Data 12 - dark blue
            0.6667 	0.184 	0.11    % Data 13 - red
            0.95    0.45    0.45    % Data 14 - light red
            0.88    0.75    0.73    % Data 15 - light pink
            0.10    0.49    0.47    % Data 16 - dark cyan
            0.6350 	0.0780 	0.1840  % Data 17 - dark red
            0.54    0.63    0.22    % Data 18 - greenish yellow
            1.00    0.10    0.60    % Data 19 - strong pink
            0.99    0.41    0.23    % Data 20 - strong orange
            ];
    else
        error('background has to be either ''light'' or ''dark''!')
    end
    
elseif strcmp(colourSuiteName,'bkr8')  %blue - black - red
    %% 'bkr8'
    if strcmp(background,'light')
        ColorSet = [
            0.0     0.0     0.3     % Data 1 - blue   dark-light-dark
            0.1     0.1     0.5     % Data 2
            0.2     0.2     0.7     % Data 3
            0.4     0.4     0.8     % Data 4
            0.8     0.4     0.4     % Data 5
            0.7     0.2     0.2     % Data 6
            0.5     0.1     0.1     % Data 7
            0.3     0.0     0.0     % Data 8
            ];
%             0.4     0.4     0.9     % Data 1 - blue   light-dark-light
%             0.2     0.2     0.8     % Data 2
%             0.1     0.1     0.6     % Data 3
%             0.0     0.0     0.4     % Data 4
%             0.4     0.0     0.0     % Data 5
%             0.6     0.1     0.1     % Data 6
%             0.8     0.2     0.2     % Data 7
%             0.9     0.4     0.4     % Data 8
%             ];
    elseif strcmp(background,'dark')
        ColorSet = [
            0.6     0.6     1.0     % Data 1 - blue   light-dark-light
            0.4     0.4     0.9     % Data 2
            0.3     0.3     0.7     % Data 3
            0.2     0.2     0.5     % Data 4
            0.5     0.2     0.2     % Data 5
            0.7     0.3     0.3     % Data 6
            0.9     0.4     0.4     % Data 7
            1.0     0.6     0.6     % Data 8
            ];
%             0.2     0.2     0.5     % Data 1 - blue   dark-light-dark
%             0.3     0.3     0.7     % Data 2
%             0.4     0.4     0.9     % Data 3
%             0.6     0.6     1.0     % Data 4
%             1.0     0.6     0.6     % Data 5
%             0.9     0.4     0.4     % Data 6
%             0.7     0.3     0.3     % Data 7
%             0.5     0.2     0.2     % Data 8
%             ];
    else
        error('background has to be either ''light'' or ''dark''!')
    end
    
elseif strcmp(colourSuiteName,'bkr5')  %blue - black - red
    %% 'bkr5'
    ColorSet = [
        0.1     0.1     0.5     % Data 1 - blue
        1.0     0.5     0.5     % Data 5 - reddish
        0.9     0.3     0.3     % Data 6 - reddish
        0.7     0.2     0.2     % Data 7 - reddish
        0.5     0.0     0.0     % Data 8 - reddish
        ];
    
elseif strcmp(colourSuiteName,'rb4')  %blue - black - red
    %% 'rb4'
    ColorSet = [
        0.6     0.0     0.0     % Data 1 - reddish dark
        1.0     0.4     0.4     % Data 7 - reddish light
        0.4     0.4     1.0     % Data 1 - blueish
        0.0     0.0     0.6     % Data 1 - blueish
        ];
    
elseif strcmp(colourSuiteName,'r3')  %blue - black - red
    %% 'r3'
    ColorSet = [
        0.6     0.0     0.0     % Data 1 - reddish dark
        0.8     0.2     0.2     % Data 5 - reddish
        1.0     0.4     0.4     % Data 7 - reddish light
        ];
    
elseif strcmp(colourSuiteName,'bkr3')  %blue - black - red
    %% 'bkr3'
    ColorSet = [
        0.7     0.2     0.2     % Data 7 - reddish
        1.0     0.5     0.5     % Data 5 - reddish
        0.1     0.1     0.5     % Data 1 - blue
        ];
    
elseif strcmp(colourSuiteName,'bkr2')  %blue - black - red
    %% 'bkr23'
    ColorSet = [
        0.7     0.1     0.1     % Data 7 - reddish
        0.1     0.1     0.7     % Data 1 - blue
        ];
    
end

%% OUTPUT COLOUR ARRAY
opColor         = ColorSet(iColor,:);      

end







