
%%                                                  MANTLE DIAGNOSTICS 1.72

% calculates connected areas by accounting for MD.addFactor times the area of
% the original plot: one part added at x=0 and one other part added at x=end

% evaluates the residual temperature
% field indicating +1 for hot plumes and -1 for cold plumes and 0 for the residual field
% ( hot plumes are defined by e.g. Tmean+0.5*(Tmax-Tmean) )

%                                                Fabio Crameri, 19.06.2018

function [MANTLE] = f_DiagnosticsMantle(FILE,GRID,SETUP,SWITCH,PLOT)

%% DEFAULTS
MD.dummy = [];
if ~isfield(MD,'plumeDefinition');      	MD.plumeDefinition      	= 2;            end     %1: solely by temperature, 2: Temperature & radial velocity
if ~isfield(MD,'plotPLUMES');               MD.plotPLUMES               = logical(0); 	end     %plot comparison of all anomalies and selected plumes
if ~isfield(MD,'addFactor');                MD.addFactor                = 0.25;         end     %percent of total x-extend that is added at x=1 and x=end
if ~isfield(MD,'upperDepthThresholdHot'); 	MD.upperDepthThresholdHot 	= 0.8;          end     %upper threshold; fraction of mantle depth (1: bottom, 0: top)
if ~isfield(MD,'lowerDepthThresholdHot'); 	MD.lowerDepthThresholdHot 	= 0.9;          end     %lower threshold; fraction of mantle depth (1: bottom, 0: top)
if ~isfield(MD,'upperDepthThresholdCold');	MD.upperDepthThresholdCold	= 0.15;         end     %upper threshold; fraction of mantle depth (1: bottom, 0: top)
if ~isfield(MD,'lowerDepthThresholdCold');	MD.lowerDepthThresholdCold	= 0.25;     	end     %lower threshold; fraction of mantle depth (1: bottom, 0: top)
if ~isfield(MD,'residualMode');             MD.residualMode             = 2;            end     %1: horizontal, 2: horizontal band, 3: global, 4: regional

%% DEFAULT OUTPUT FIELDS
MANTLE.DiagnosticsFailed        = false;
MANTLE.upWelling                = NaN;      %1 for upwelling, 0 else
MANTLE.downWelling              = NaN;      %1 for downwelling, 0 else
MANTLE.plumesHot                = NaN;      %1 for hot plumes, 0 else
MANTLE.plumesCold               = NaN;  	%1 for cold plumes, 0 else
MANTLE.numHotPlumes             = NaN;    	%num
MANTLE.numColdPlumes            = NaN;  	%num
MANTLE.UpwellingVolume          = NaN;   	%[nd] or [m^2]or[m^3]
MANTLE.DownwellingVolume        = NaN;  	%[nd] or [m^2]or[m^3]
MANTLE.UpwellingVolPerc         = NaN;      %in [% of model domain]
MANTLE.DownwellingVolPerc       = NaN;  	%in [% of model domain]

MANTLE.activeUpwelling          = NaN;  	%1 for active upwelling
MANTLE.activeDownwelling        = NaN;   	%1 for active downwelling
MANTLE.numActUpwelling          = NaN;    	%num
MANTLE.numActDownwelling        = NaN;   	%num
MANTLE.ActUpwellingVolume       = NaN;     	%[nd] or [m^2]or[m^3]
MANTLE.ActDownwellingVolume    	= NaN;     	%[nd] or [m^2]or[m^3]
MANTLE.ActUpwellingVolPerc      = NaN;   	%in [% of total upwelling]
MANTLE.ActDownwellingVolPerc  	= NaN;    	%in [% of total downwelling]

MANTLE.passiveUpwelling         = NaN;    	%1 for passive upwelling
MANTLE.passiveDownwelling       = NaN;   	%1 for passive downwelling
MANTLE.numPassUpwelling         = NaN;    	%num
MANTLE.numPassDownwelling       = NaN;    	%num
MANTLE.PassUpwellingVolume   	= NaN;    	%[nd] or [m^2]or[m^3]
MANTLE.PassDownwellingVolume 	= NaN;      %[nd] or [m^2]or[m^3]
MANTLE.PassUpwellingVolPerc  	= NaN;  	%in [% of total upwelling]
MANTLE.PassDownwellingVolPerc 	= NaN;      %in [% of total downwelling]

MANTLE.plumeHotNumberUM         = NaN;    	%num
MANTLE.plumeHotVHmaxUM          = NaN;    	%[plotting dim]
MANTLE.plumeHotVHminUM          = NaN;    	%[plotting dim]
MANTLE.plumeHotVHmeanUM         = NaN;    	%[plotting dim]
MANTLE.plumeHotNumberMM         = NaN;    	%num
MANTLE.plumeHotVHmaxMM          = NaN;    	%[plotting dim]
MANTLE.plumeHotVHminMM          = NaN;    	%[plotting dim]
MANTLE.plumeHotVHmeanMM         = NaN;    	%[plotting dim]
MANTLE.plumeHotNumberLM         = NaN;    	%num
MANTLE.plumeHotVHmaxLM          = NaN;    	%[plotting dim]
MANTLE.plumeHotVHminLM          = NaN;    	%[plotting dim]
MANTLE.plumeHotVHmeanLM         = NaN;    	%[plotting dim]

MANTLE.plumeColdNumberUM      	= NaN;    	%num
MANTLE.plumeColdVHmaxUM     	= NaN;    	%[plotting dim]
MANTLE.plumeColdVHminUM      	= NaN;    	%[plotting dim]
MANTLE.plumeColdVHmeanUM    	= NaN;    	%[plotting dim]
MANTLE.plumeColdNumberMM    	= NaN;    	%num
MANTLE.plumeColdVHmaxMM      	= NaN;    	%[plotting dim]
MANTLE.plumeColdVHminMM     	= NaN;    	%[plotting dim]
MANTLE.plumeColdVHmeanMM        = NaN;    	%[plotting dim]
MANTLE.plumeColdNumberLM     	= NaN;    	%num
MANTLE.plumeColdVHmaxLM      	= NaN;    	%[plotting dim]
MANTLE.plumeColdVHminLM     	= NaN;    	%[plotting dim]
MANTLE.plumeColdVHmeanLM        = NaN;    	%[plotting dim]

if strcmp(GRID.Type,'yinyang')
    %add here......
end

%% INPUT ADJUSTMENTS
if strcmp(GRID.Type,'yinyang') %grid might NOT be flipped in yinyang
    warning('check if these values need to be flipped upside down!');
%     MD.upperDepthThresholdHot  = 1-MD.upperDepthThresholdHot;
%     MD.lowerDepthThresholdHot  = 1-MD.lowerDepthThresholdHot;
%     MD.upperDepthThresholdCold = 1-MD.upperDepthThresholdCold;
%     MD.lowerDepthThresholdCold = 1-MD.lowerDepthThresholdCold;
end

%% SETUP SWITCHES
if strcmp(GRID.Type,'yinyang')
    nb = 2;
else
    nb = 1;
end

%% READ INPUT DATA
%temperature
DATA.Task                   = 'ImportFieldData';
DATA.Field2Import           = 'Temperature';
DATA.FieldAbbreviation      = 'T';
DATA.StopExecutionIfNotFound = true;
[DATA,PLOT] = f_Import(DATA,FILE,GRID,PLOT,SWITCH);
interiorIndexLow            = floor( size(GRID.Z_3D,3)*1/10 );  %bottom of the mantle
interiorIndexHigh           = ceil( size(GRID.Z_3D,3)*8/10 );   %top of the mantle
if strcmp(GRID.Type,'yinyang')
    T_3D        = PLOT.T_3Dyin; T_3D_yang   = PLOT.T_3Dyang;
    Tmin        = min([PLOT.T_3Dyin(:);PLOT.T_3Dyang(:)]);
    Tmax        = max([PLOT.T_3Dyin(:);PLOT.T_3Dyang(:)]);
    dummy       = [PLOT.T_3Dyin(:,:,interiorIndexLow:interiorIndexHigh);PLOT.T_3Dyang(:,:,interiorIndexLow:interiorIndexHigh)];
    Tmedian    	= median(dummy(:)); %handle with care: median does not consider effects of an air layer or refined/spherical grid...
else %all other grid types
    T_3D        = PLOT.T_3D;
    Tmin        = min(PLOT.T_3D(:));
    Tmax        = max(PLOT.T_3D(:));
    dummy       = PLOT.T_3D(:,:,interiorIndexLow:interiorIndexHigh);
    Tmedian  	= median(dummy(:)); %handle with care: median does not consider effects of an air layer or refined/spherical grid...
end
clearvars dummy
if DATA.NotFound
    MANTLE.DiagnosticsFailed	= true;
    warning off backtrace
    disp(' '); warning('Mantle diagnostics failed due to missing temperature data.'); disp(' ');
    warning on backtrace
    return
    
end

%velocity
DATA.Task                   = 'ImportFieldData';
DATA.Field2Import           = 'Velocity';
DATA.FieldAbbreviation      = 'V';
DATA.StopExecutionIfNotFound = true;
[DATA,PLOT] = f_Import(DATA,FILE,GRID,PLOT,SWITCH);
if strcmp(GRID.Type,'yinyang')
%     VX_3D = PLOT.VX_3Dyin; VX_3D_yang = PLOT.VX_3Dyang;
%     VY_3D = PLOT.VY_3Dyin; VY_3D_yang = PLOT.VY_3Dyang;
    VH_3D = PLOT.VH_3Dyin; VH_3D_yang = PLOT.VH_3Dyang;
    VZ_3D = PLOT.VZ_3Dyin; VZ_3D_yang = PLOT.VZ_3Dyang;
    VZmax   = max(abs([VZ_3D(:);VZ_3D_yang(:)]));   %doesn't take variable gridspacing into account....
else %all other grid types
%     VX_3D   = PLOT.VX_3D;
%     VY_3D   = PLOT.VY_3D;
    VH_3D   = PLOT.VH_3D;
    VZ_3D   = PLOT.VZ_3D;
    VZmax   = max(abs(VZ_3D(:)));   %doesn't take variable gridspacing into account....
end
if DATA.NotFound
    MANTLE.DiagnosticsFailed	= true;
    warning off backtrace
    disp(' '); warning('Mantle diagnostics failed due to missing velocity data.'); disp(' ');
    warning on backtrace
    return
    
end

%% DIMENSIONALISATION
VH_3D           = VH_3D*SETUP.Vscale;
if strcmp(GRID.Type,'yinyang')
    VH_3D_yang 	= VH_3D_yang*SETUP.Vscale;
end

%% CALCULATE RESIDUAL TEMPERATURE FIELD
%initiation
Plumes3D = zeros(size(T_3D));
Tres3D = Plumes3D;

if MD.residualMode==1 %Standard horizontal residual
    SWITCH.customFieldTask  = 'Horizontal residual';
elseif MD.residualMode==2 %Horizontal-band residual
    SWITCH.customFieldTask  = 'Horizontal-band residual';
elseif MD.residualMode==3 %Global residual
    SWITCH.customFieldTask  = 'Global residual';
elseif MD.residualMode==4 %Regional residual
    SWITCH.customFieldTask  = 'Regional residual';
end
[VAR] = f_makeField(1,FILE,GRID,SETUP,SWITCH,PLOT,1,1);
%convert variables
if strcmp(GRID.Type,'yinyang')
    Tres3D              = VAR.var2d_yin;
    Tres3D_yang         = VAR.var2d_yang;
    %ADD horizMean etc here for yin and yang ..................
    error('from here on not implemented for yinyang grid...')
    %XXXXX
else
    if strcmp(GRID.Dim,'2-D')
        Tres3D(:,1,:) 	= VAR.var2d;
    else %strcmp(GRID.Dim,'3-D')
        Tres3D          = VAR.var2d;
    end
    horizMeanTres       = VAR.meanTres; %might be regional values
    horizMin            = VAR.minTres;
    horizMax            = VAR.maxTres;
end
clearvars VAR


%% FIND ACTIVE PLUMES
%initialising
Plumes3D = zeros(size(Tres3D));
thrHot = Plumes3D;
thrCold = Plumes3D;
if strcmp(GRID.Type,'yinyang'); Plumes3D_yang = Plumes3D; end

%start plume diagnostics
thrHot                    	= horizMeanTres + PLOT.pHot.*(horizMax-horizMeanTres);	%after Labrosse (EPSL,2002)
thrCold                 	= horizMeanTres + PLOT.pCold.*(horizMin-horizMeanTres);	%after Labrosse (EPSL,2002)

Plumes3D(Tres3D>thrHot)   	= 1;            	%hot plumes
Plumes3D(Tres3D<thrCold)  	= -1;              	%cold plumes

if strcmp(GRID.Type,'yinyang')
    Plumes3D_yang(Tres3D_yang>thrHot_yang)    	= 1;  	%hot plumes
    Plumes3D_yang(Tres3D_yang<thrCold_yang)  	= -1;  	%cold plumes
    %XXXXX thrHot thrCold
    
end
clearvars horizMeanT horizMeanTres horizMax horizMin thrHot thrCold dummy dummyX dummyY

if logical(0)
    figure(3)
   hold on
   x(:,:) = GRID.X_3Dp(:,1,:);
   z(:,:) = GRID.Z_3Dp(:,1,:);
   p(:,:) = Plumes3D(:,1,:);
   phot = zeros(size(p));
   phot(p==1) = 1;
   phot = bwmorph(phot,'thicken',1);
   phot = bwmorph(phot,'bridge');

   pcold = zeros(size(p));
   pcold(p==-1) = 1;
%    pcold = bwmorph(pcold,'thicken',2);
   pcold = bwmorph(pcold,'bridge');
   
   p2 = phot-pcold;
   contourf(x,z,p2)
   colorbar
   axis ij
    figure(1)
end

%% FIND UP- AND DOWNWELLINGS
thrVZ                       = 1/100 *VZmax;          %define threshold for up/down wellings <<<<<<<<<<<<<<<<<<
upWelling                   = zeros(size(VZ_3D));  	%nothing
downWelling              	= zeros(size(VZ_3D));   %nothing
upWelling(VZ_3D>thrVZ)      = 1;                  	%upwelling
downWelling(VZ_3D<-thrVZ)	= 1;                    %downwelling
if strcmp(GRID.Type,'yinyang')
    upWelling_yang                      = zeros(size(VZ_3D_yang)); 	%nothing
    downWelling_yang                    = zeros(size(VZ_3D_yang)); 	%nothing
    upWelling_yang(VZ_3D_yang>thrVZ) 	= 1;                        %upwelling
    downWelling_yang(VZ_3D_yang<-thrVZ) = 1;                        %downwelling
end

%% ACCOUNT FOR PERIODIC BOUNDARIES
%check for plumes crossing periodic boundaries:
add_factor          = MD.addFactor;      %percent of total x-extent that is added at x=1 and x=end
%add some slices at x=1 and x=end
PlumesOrig          = Plumes3D;
extentXgrid         = false;
extentYgrid         = false;
nx_orig             = size(PlumesOrig,1);
ny_orig             = size(PlumesOrig,2);
nx_add              = nx_orig*add_factor;
ny_add              = ny_orig*add_factor;
if strcmp(GRID.Type,'yinyang')
    extentYgrid     = true;
elseif strcmp(GRID.Type,'Cartesian')
    if strcmp(GRID.Dim,'2-D')
        if size(Plumes3D,1)>1 && size(Plumes3D,2)==1 && strcmp(GRID.BCxx,'periodic'); extentXgrid = true; end
        if size(Plumes3D,1)==1 && size(Plumes3D,2)>1 && strcmp(GRID.BCyy,'periodic'); extentYgrid = true; end
    elseif strcmp(GRID.Dim,'3-D')
        if strcmp(GRID.BCxx,'periodic'); extentXgrid = true; end
        if strcmp(GRID.BCyy,'periodic'); extentYgrid = true; end
        warning(['MANTLE DIAGNOSTICS: Grid type ',GRID.Type,' in 3-D not tested yet!'])
    end
elseif strcmp(GRID.Type,'cylindrical')
    if size(Plumes3D,1)>1 && size(Plumes3D,2)==1 && strcmp(GRID.BCxx,'periodic'); extentXgrid = true; end
    if size(Plumes3D,1)==1 && size(Plumes3D,2)>1 && strcmp(GRID.BCyy,'periodic'); extentYgrid = true; end
else
    error(['Grid type ',GRID.Type,' not found!'])
end
if extentXgrid
    Plumes3D        = [Plumes3D((end-nx_add+1):end,:,:); Plumes3D; Plumes3D(1:nx_add,:,:)];
    upWelling       = [upWelling((end-nx_add+1):end,:,:); upWelling; upWelling(1:nx_add,:,:)];
    downWelling     = [downWelling((end-nx_add+1):end,:,:); downWelling; downWelling(1:nx_add,:,:)];
    if strcmp(GRID.Type,'yinyang')
        Plumes3D_yang 	= [Plumes3D_yang((end-nx_add+1):end,:,:); Plumes3D_yang; Plumes3D_yang(1:nx_add,:,:)];
        upWelling_yang 	= [upWelling_yang((end-nx_add+1):end,:,:); upWelling_yang; upWelling_yang(1:nx_add,:,:)];
        downWelling_yang= [downWelling_yang((end-nx_add+1):end,:,:); downWelling_yang; downWelling_yang(1:nx_add,:,:)];
    end
end
if extentYgrid
    Plumes3D     	= [Plumes3D(:,(end-ny_add+1):end,:), Plumes3D, Plumes3D(:,1:ny_add,:)];
    upWelling       = [upWelling(:,(end-ny_add+1):end,:), upWelling, upWelling(:,1:ny_add,:)];
    downWelling     = [downWelling(:,(end-ny_add+1):end,:), downWelling, downWelling(:,1:ny_add,:)];
    if strcmp(GRID.Type,'yinyang')
        Plumes3D_yang 	= [Plumes3D_yang(:,(end-ny_add+1):end,:), Plumes3D_yang, Plumes3D_yang(:,1:ny_add,:)];
        upWelling_yang	= [upWelling_yang(:,(end-ny_add+1):end,:), upWelling_yang, upWelling_yang(:,1:ny_add,:)];
        downWelling_yang= [downWelling_yang(:,(end-ny_add+1):end,:), downWelling_yang, downWelling_yang(:,1:ny_add,:)];
    end
end

for ib=1:nb
    Plumes3Dh = zeros(size(Plumes3D)); Plumes3Dc = Plumes3Dh;
    if ib==1
        Plumes3Dh(Plumes3D==1)  = 1;
        Plumes3Dc(Plumes3D==-1) = 1;
    elseif ib==2
        Plumes3Dh(Plumes3D_yang==1)  = 1;
        Plumes3Dc(Plumes3D_yang==-1) = 1;
    end
    %% OPTIMISE DATA I
    if logical(1)
        if strcmp(GRID.Dim,'2-D')
            dummyh(:,:)         = Plumes3Dh(:,1,:); %make 2-dimensional
            dummyc(:,:)         = Plumes3Dc(:,1,:); %make 2-dimensional
            %thicken
%             dummyh              = bwmorph(dummyh,'thicken',1);
%             dummyc              = bwmorph(dummyc,'thicken',1);
            %bridge
            dummyh              = bwmorph(dummyh,'bridge');
            dummyc              = bwmorph(dummyc,'bridge');
            Plumes3Dh(:,1,:)    = dummyh(:,:);
            Plumes3Dc(:,1,:)    = dummyc(:,:);
            clearvars dummyh dummyc
        elseif strcmp(GRID.Dim,'3-D')
            if SWITCH.Verbose; warning('Optimising plume data in 3-D not possible yet'); end
        end
    end
    
    if logical(0)
        figure(3)
        x(:,:) = GRID.X_3Dp(:,1,:);
        z(:,:) = GRID.Z_3Dp(:,1,:);
        p(:,:) = Plumes3Dh(:,1,:);
        contourf(x,z,p)
        colorbar
        axis ij
        figure(1)
    end
   
    %% CHECK CONNECTIVITY FOR AREA SIZES
    CCph      	= bwconncomp(Plumes3Dh);         %HOT PLUMES
    numPixelsPh	= cellfun(@numel,CCph.PixelIdxList); %number of connected pixels in each connected area
    CCpc      	= bwconncomp(Plumes3Dc);         %COLD PLUMES
    numPixelsPc	= cellfun(@numel,CCpc.PixelIdxList); %number of connected pixels in each connected area
    CCuw        = bwconncomp(upWelling);       %UPWELLINGS
    numPixelsUW	= cellfun(@numel,CCuw.PixelIdxList); %number of connected pixels in each connected area
    CCdw        = bwconncomp(downWelling);     %DOWNWELLINGS
    numPixelsDW	= cellfun(@numel,CCdw.PixelIdxList); %number of connected pixels in each connected area
    
    %% REMOVING SMALL ANOMALIES
    removeSmallAnomalies = logical(1);
    plumesBhot  = Plumes3Dh;  	%cold plumes
    plumesBcold = Plumes3Dc;  	%cold plumes
    if removeSmallAnomalies
        % *********************** small area criterion <<<<<<<<<<<<<<<<
        % [size_largest,ind_largest]	= max(numPixels);   %find single most largest area
        sizeThreshold       = 1/5* size(Plumes3Dh,3);   %find areas larger than (1/5*nz) pixels
        if strcmp(GRID.Dim,'3-D')
            sizeThreshold       = sizeThreshold *4/3*sqrt(sizeThreshold/pi); %find areas larger than x pixels
        end
        indLargePh          	= find(numPixelsPh<sizeThreshold);
        indLargePc          	= find(numPixelsPc<sizeThreshold);
        % ***********************
        for i_ind=1:size(indLargePh,2)
            plumesBhot(CCph.PixelIdxList{indLargePh(i_ind)}) = 0;
        end
        for i_ind=1:size(indLargePc,2)
            plumesBcold(CCpc.PixelIdxList{indLargePc(i_ind)}) = 0;
        end
    end
    
    %% SETTING UP HOT AND COLD ANOMALIES after criterion
    if ib==1
        plumesHot             	= plumesBhot;   %hot plumes
        plumesCold              = plumesBcold;  %cold plumes
    elseif ib==2
        plumesHot_yang      	= plumesBhot;   %hot plumes
        plumesCold_yang     	= plumesBcold;	%cold plumes
    end
    clearvars plumesBhot plumesBcold
end

%% CONNECTIVITY CHECK WITH CORRESPONDING BOUNDARY LAYER
% ...AND CHECK FOR PLUME EXTENSION THROUGHOUT UPPER-AND LOWER-DEPTH THRESHOLDS
% This uses PLOT.Z_3Dp, which is always flipped and actual depthCCPhot   = bwconncomp(plumesHot);
CCPhot  = bwconncomp(plumesHot);
CCPcold  = bwconncomp(plumesCold);
if strcmp(GRID.Type,'yinyang')
    CCPhot_yang   = bwconncomp(plumesHot_yang);
    CCPcold_yang  = bwconncomp(plumesCold_yang);
end
Ztop    = 0;
Zbot    = max(GRID.Z_3Dp(:));
Zdiff   = Zbot-Ztop;
if Zdiff<=0; error('Zdiff should be >0'); end
for ib=1:nb
    for plume_kind=1:2
        if plume_kind==1  %HOT
            if ib==1
                CC_kind = CCPhot; 
            else
                CC_kind = CCPhot_yang; 
            end
            ZtopThreshold  	= Ztop + Zdiff*MD.upperDepthThresholdHot;
            ZbotThreshold  	= Ztop + Zdiff*MD.lowerDepthThresholdHot;
        elseif plume_kind==2  %COLD
            if ib==1
                CC_kind = CCPcold;
            elseif ib==2
                CC_kind = CCPcold_yang;
            end
            ZtopThreshold  	= Ztop + Zdiff*MD.upperDepthThresholdCold;
            ZbotThreshold 	= Ztop + Zdiff*MD.lowerDepthThresholdCold;
        end
        for i_area=1:size(CC_kind.PixelIdxList,2)  %loop all connected areas
            surf_connection = false;
            bot_connection = false;
            for ip=1:size(CC_kind.PixelIdxList{1,i_area},1)  %loop all pixels of an area
                i_pixel = CC_kind.PixelIdxList{1,i_area}(ip,1);
                %[x,y,z] = ind2sub(size(PLUMES),i_pixel);
                if GRID.Z_3Dp(i_pixel)<=ZtopThreshold %is connected to the top (0)
                    surf_connection = true;
                end
                if GRID.Z_3Dp(i_pixel)>=ZbotThreshold %is connected to the bottom (1)
                    bot_connection = true;
                end
                if surf_connection && bot_connection
                    break   %this is a plume exceeding top to bottom levels! check next.
                end
            end
            
            if surf_connection && bot_connection %of defined depth thresholds
                %keep area
            else %remove area: this is no plume
                if plume_kind==1  %HOT
                    if ib==1
                        plumesHot(CC_kind.PixelIdxList{i_area}) = 0;
                    elseif ib==2
                        plumesHot_yang(CC_kind.PixelIdxList{i_area}) = 0;
                    end
                elseif plume_kind==2  %COLD
                    if ib==1
                        plumesCold(CC_kind.PixelIdxList{i_area}) = 0;
                    elseif ib==2
                        plumesCold_yang(CC_kind.PixelIdxList{i_area}) = 0;
                    end
                end
            end
        end
    end
end

%% REMOVING GRID EXTENSION (BACK TO ORIGINAL SIZE)
if extentXgrid
    Plumes3D        = Plumes3D((nx_add+1):end-nx_add,:,:);
    plumesHot       = plumesHot((nx_add+1):end-nx_add,:,:);
    plumesCold      = plumesCold((nx_add+1):end-nx_add,:,:);
    upWelling       = upWelling((nx_add+1):end-nx_add,:,:);
    downWelling     = downWelling((nx_add+1):end-nx_add,:,:);
    if strcmp(GRID.Type,'yinyang')
        Plumes3D_yang     	= Plumes3D_yang((nx_add+1):end-nx_add,:,:);
        plumesHot_yang   	= plumesHot_yang((nx_add+1):end-nx_add,:,:);
        plumesCold_yang    	= plumesCold_yang((nx_add+1):end-nx_add,:,:);
        upWelling_yang   	= upWelling_yang((nx_add+1):end-nx_add,:,:);
        downWelling_yang  	= downWelling_yang((nx_add+1):end-nx_add,:,:);
    end
end
if extentYgrid
    Plumes3D        = Plumes3D(:,(ny_add+1):end-ny_add,:);
    plumesHot       = plumesHot(:,(ny_add+1):end-ny_add,:);
    plumesCold      = plumesCold(:,(ny_add+1):end-ny_add,:);
    upWelling       = upWelling(:,(ny_add+1):end-ny_add,:);
    downWelling 	= downWelling(:,(ny_add+1):end-ny_add,:);
    if strcmp(GRID.Type,'yinyang')
        Plumes3D_yang     	= Plumes3D_yang(:,(ny_add+1):end-ny_add,:);
        plumesHot_yang   	= plumesHot_yang(:,(ny_add+1):end-ny_add,:);
        plumesCold_yang   	= plumesCold_yang(:,(ny_add+1):end-ny_add,:);
        upWelling_yang    	= upWelling_yang(:,(ny_add+1):end-ny_add,:);
        downWelling_yang 	= downWelling_yang(:,(ny_add+1):end-ny_add,:);
    end
end

%% DESCRIMINATE BETWEEN ACTIVE AND PASSIVE UP-/DOWNWELLING
passiveUpwelling    = upWelling-plumesHot;      passiveUpwelling(passiveUpwelling<0) = 0;
passiveDownwelling 	= downWelling-plumesCold;   passiveDownwelling(passiveDownwelling<0) = 0;
activeUpwelling     = zeros(size(upWelling));   activeUpwelling(upWelling & plumesHot) = 1;
activeDownwelling	= zeros(size(downWelling)); activeDownwelling(downWelling & plumesCold) = 1;
if strcmp(GRID.Type,'yinyang')
    passiveUpwelling_yang 	= upWelling_yang-plumesHot_yang; 	passiveUpwelling_yang(passiveUpwelling_yang<0) = 0;
    passiveDownwelling_yang	= downWelling_yang-plumesCold_yang;	passiveDownwelling_yang(passiveDownwelling_yang<0) = 0;
    activeUpwelling_yang    = zeros(size(upWelling_yang));      activeUpwelling_yang(upWelling_yang & plumesHot_yang) = 1;
    activeDownwelling_yang	= zeros(size(downWelling_yang));    activeDownwelling_yang(downWelling_yang & plumesCold_yang) = 1;
end

%% PLUME DEFINITION
if MD.plumeDefinition==1 %defined solely by temperature
%     plumesHot       = plumesHot;
%     plumesCold      = plumesCold;
elseif MD.plumeDefinition==2 %defined by temperature and vertical velocity
    plumesHot       = activeUpwelling;
    plumesCold      = activeDownwelling;
end


if ~strcmp(GRID.Type,'yinyang')
    %% DETAILS OF FOUND ANOMALIES
    %derive horizontal slices
    depthLevelPlumeSlices  = [0.7, 0.5, 0.1];  %values between 1 (surface) and 0 (bottom)
    
    DomainDepthMax      = max(GRID.Z_3Dp(:));
    DomainDepthMin      = min(GRID.Z_3Dp(GRID.Z_3Dp>0));
    DomainDepth         = abs( DomainDepthMax - DomainDepthMin );
    
    depthLevelSlices    = DomainDepthMax - depthLevelPlumeSlices.*DomainDepth;  %plotting values
    depthLevelSlicesIdx = zeros(size(depthLevelSlices)); %array indices
    for id=1:length(depthLevelSlices)
        [~,depthLevelSlicesIdx(1,id)]	= min(abs(GRID.Z_3Dp(1,1,:)-depthLevelSlices(id)));  %index of closest value to mean LAB depth further up in the plate
    end
    
    %extract plumes at these depths
    plumesHotSlice      = plumesHot(:,:,depthLevelSlicesIdx);
    plumesColdSlice   	= plumesCold(:,:,depthLevelSlicesIdx);
    
    %define point sources for plumes
    numPlumesHotSlice = zeros(1,length(depthLevelSlices));
    for id=1:length(depthLevelSlices)
        %     CC11        = bwconncomp(plumesHotSlice(:,:,id))
        plumesHotSlice(:,:,id)      = bwmorph(plumesHotSlice(:,:,id),'shrink',Inf);
        numPlumesHotSlice(id)    	= sum(plumesHotSlice(:,:,id));
        plumesColdSlice(:,:,id) 	= bwmorph(plumesColdSlice(:,:,id),'shrink',Inf);
        numPlumesColdSlice(id)    	= sum(plumesColdSlice(:,:,id));
    end
    
    %create hot plume data arrays
    maxNumPlumesHotPerSlice         = max(numPlumesHotSlice(:));
    dummy               = zeros(size(plumesHotSlice,1),size(plumesHotSlice,2))*NaN;
    vhFullSlice         = dummy;
    vhPlumeHotSlices    = zeros(length(depthLevelSlices),maxNumPlumesHotPerSlice)*NaN; %[slices,plumes]
    xPlumeHotSlices     = vhPlumeHotSlices;
    yPlumeHotSlices     = vhPlumeHotSlices;
    zPlumeHotSlices     = vhPlumeHotSlices;
    for id=1:length(depthLevelSlices)
        %extract horizontal position
        if max(plumesHotSlice(:,:,id))>0
            dummyNplumes = size(dummy(plumesHotSlice(:,:,id)==1),1);
            dummy(:,:)                          = GRID.X_3Dp(:,:,depthLevelSlicesIdx(id));
            xPlumeHotSlices(id,1:dummyNplumes)     = dummy(plumesHotSlice(:,:,id)==1);
            dummy(:,:)                          = GRID.Y_3Dp(:,:,depthLevelSlicesIdx(id));
            yPlumeHotSlices(id,1:dummyNplumes) 	= dummy(plumesHotSlice(:,:,id)==1);
            dummy(:,:)                          = GRID.Z_3Dp(:,:,depthLevelSlicesIdx(id));
            zPlumeHotSlices(id,1:dummyNplumes) 	= dummy(plumesHotSlice(:,:,id)==1);
            %extract horizontal velocity (i.e., migration magnitude) of these points in the different slices
            vhFullSlice(:,:)                    = VH_3D(:,:,depthLevelSlicesIdx(id));
            vhPlumeHotSlices(id,1:dummyNplumes)	= vhFullSlice(plumesHotSlice(:,:,id)==1);
        end
    end
    clearvars dummy dummyNplumes
    
    %create cold plume data arrays
    maxNumPlumesColdPerSlice         = max(numPlumesColdSlice(:));
    dummy               = zeros(size(plumesColdSlice,1),size(plumesColdSlice,2))*NaN;
    vhFullSlice         = dummy;
    vhPlumeColdSlices   = zeros(length(depthLevelSlices),maxNumPlumesColdPerSlice)*NaN; %[slices,plumes]
    xPlumeColdSlices    = vhPlumeColdSlices;
    yPlumeColdSlices    = vhPlumeColdSlices;
    zPlumeColdSlices    = vhPlumeColdSlices;
    for id=1:length(depthLevelSlices)
        %extract horizontal position
        if max(plumesColdSlice(:,:,id))>0
            dummyNplumes = size(dummy(plumesColdSlice(:,:,id)==1),1);
            dummy(:,:)                          = GRID.X_3Dp(:,:,depthLevelSlicesIdx(id));
            xPlumeColdSlices(id,1:dummyNplumes)	= dummy(plumesColdSlice(:,:,id)==1);
            dummy(:,:)                          = GRID.Y_3Dp(:,:,depthLevelSlicesIdx(id));
            yPlumeColdSlices(id,1:dummyNplumes)	= dummy(plumesColdSlice(:,:,id)==1);
            dummy(:,:)                          = GRID.Z_3Dp(:,:,depthLevelSlicesIdx(id));
            zPlumeColdSlices(id,1:dummyNplumes)	= dummy(plumesColdSlice(:,:,id)==1);
            %extract horizontal velocity (i.e., migration magnitude) of these points in the different slices
            vhFullSlice(:,:)                    = VH_3D(:,:,depthLevelSlicesIdx(id));
            vhPlumeColdSlices(id,1:dummyNplumes)	= vhFullSlice(plumesColdSlice(:,:,id)==1);
        end
    end
    clearvars dummy dummyNplumes
    
    %output diagnostics
    %Upper Mantle
    MANTLE.plumeHotNumberUM     = numPlumesHotSlice(1);
    MANTLE.plumeHotVHmaxUM      = max(vhPlumeHotSlices(1,:));
    MANTLE.plumeHotVHminUM    	= min(vhPlumeHotSlices(1,:));
    MANTLE.plumeHotVHmeanUM   	= nanmean(vhPlumeHotSlices(1,:));
    MANTLE.plumeColdNumberUM  	= numPlumesColdSlice(1);
    MANTLE.plumeColdVHmaxUM   	= max(vhPlumeColdSlices(1,:));
    MANTLE.plumeColdVHminUM    	= min(vhPlumeColdSlices(1,:));
    MANTLE.plumeColdVHmeanUM   	= nanmean(vhPlumeColdSlices(1,:));
    %Mid Mantle
    MANTLE.plumeHotNumberMM     = numPlumesHotSlice(2);
    MANTLE.plumeHotVHmaxMM      = max(vhPlumeHotSlices(2,:));
    MANTLE.plumeHotVHminMM    	= min(vhPlumeHotSlices(2,:));
    MANTLE.plumeHotVHmeanMM   	= nanmean(vhPlumeHotSlices(2,:));
    MANTLE.plumeColdNumberMM  	= numPlumesColdSlice(2);
    MANTLE.plumeColdVHmaxMM    	= max(vhPlumeColdSlices(2,:));
    MANTLE.plumeColdVHminMM    	= min(vhPlumeColdSlices(2,:));
    MANTLE.plumeColdVHmeanMM   	= nanmean(vhPlumeColdSlices(2,:));
    %Lower Mantle
    MANTLE.plumeHotNumberLM     = numPlumesHotSlice(3);
    MANTLE.plumeHotVHmaxLM      = max(vhPlumeHotSlices(3,:));
    MANTLE.plumeHotVHminLM    	= min(vhPlumeHotSlices(3,:));
    MANTLE.plumeHotVHmeanLM   	= nanmean(vhPlumeHotSlices(3,:));
    MANTLE.plumeColdNumberLM  	= numPlumesColdSlice(3);
    MANTLE.plumeColdVHmaxLM    	= max(vhPlumeColdSlices(3,:));
    MANTLE.plumeColdVHminLM    	= min(vhPlumeColdSlices(3,:));
    MANTLE.plumeColdVHmeanLM   	= nanmean(vhPlumeColdSlices(3,:));
    
else
    warning('This has not been implemented yet for yinyang!')
end




%% DETAILS OF FOUND ANOMALIES
% number of hot and cold active plumes
CChot2      	= bwconncomp(plumesHot);
CCcold2         = bwconncomp(plumesCold);
if strcmp(GRID.Type,'yinyang')
    CChot2_yang         	= bwconncomp(plumesHot_yang);
    CCcold2_yang         	= bwconncomp(plumesCold_yang);
    MANTLE.numHotPlumes     = CChot2.NumObjects+CChot2_yang.NumObjects;
    MANTLE.numColdPlumes    = CCcold2.NumObjects+CCcold2_yang.NumObjects;
else
    MANTLE.numHotPlumes     = CChot2.NumObjects;
    MANTLE.numColdPlumes    = CCcold2.NumObjects;
end

%check here also for wrap-around boundaries.....................


% total volume of up- and downwelling
if strcmp(GRID.Type,'yinyang')
    MANTLE.UpwellingVolume      = sum(sum(GRID.cellVolume(upWelling(:,:,2:end)==1)))+...
        sum(sum(GRID.cellVolume(upWelling_yang(:,:,2:end)==1))); %[nd] or [m^2]or[m^3]
    MANTLE.DownwellingVolume 	= sum(sum(GRID.cellVolume(downWelling(:,:,1:end-1)==1)))+...
        sum(sum(GRID.cellVolume(downWelling_yang(:,:,1:end-1)==1))); %[nd] or [m^2]or[m^3]
else
    MANTLE.UpwellingVolume      = sum(sum(GRID.cellVolume(upWelling(:,:,2:end)==1))); %[nd] or [m^2]or[m^3]
    MANTLE.DownwellingVolume 	= sum(sum(GRID.cellVolume(downWelling(:,:,1:end-1)==1))); %[nd] or [m^2]or[m^3]
end
% percentage of total volume of up- and downwelling versus total volume model domain
MANTLE.UpwellingVolPerc     = 100 *MANTLE.UpwellingVolume /(sum(GRID.cellVolume(:))*nb); %in [% of total volume]
MANTLE.DownwellingVolPerc  	= 100 *MANTLE.DownwellingVolume /(sum(GRID.cellVolume(:))*nb); %in [% of total volume]
% area of upwellings at certain depth..................

% active up- and downwelling
MANTLE.activeUpwelling                  = activeUpwelling;
MANTLE.activeDownwelling                = activeDownwelling;
MANTLE.activeUpwelling(~plumesHot)      = 0;
MANTLE.activeDownwelling(~plumesCold)   = 0;
CCactU                                  = bwconncomp(MANTLE.activeUpwelling);
CCactD                                  = bwconncomp(MANTLE.activeDownwelling);
MANTLE.numActUpwelling                  = CCactU.NumObjects;
MANTLE.numActDownwelling                = CCactD.NumObjects;
MANTLE.ActUpwellingVolume             	= sum(sum(GRID.cellVolume(MANTLE.activeUpwelling(:,:,2:end)==1)));      %[nd] or [m^2]or[m^3]
MANTLE.ActDownwellingVolume             = sum(sum(GRID.cellVolume(MANTLE.activeDownwelling(:,:,1:end-1)==1)));  %[nd] or [m^2]or[m^3]
MANTLE.ActUpwellingVolPerc              = 100 *MANTLE.ActUpwellingVolume /MANTLE.UpwellingVolume;               %in [% of total upwelling]
MANTLE.ActDownwellingVolPerc            = 100 *MANTLE.ActDownwellingVolume /MANTLE.DownwellingVolume;           %in [% of total downwelling]

% passive up- and downwelling
MANTLE.passiveUpwelling              	= passiveUpwelling;
MANTLE.passiveDownwelling             	= passiveDownwelling;
MANTLE.passiveUpwelling(plumesHot==1)   = 0;
MANTLE.passiveDownwelling(plumesCold==1)= 0;
CCpassU                                 = bwconncomp(MANTLE.passiveUpwelling);
CCpassD                                 = bwconncomp(MANTLE.passiveDownwelling);
MANTLE.numPassUpwelling               	= CCpassU.NumObjects;
MANTLE.numPassDownwelling               = CCpassD.NumObjects;
MANTLE.PassUpwellingVolume             	= sum(sum(GRID.cellVolume(MANTLE.passiveUpwelling(:,:,2:end)==1)));      %[nd] or [m^2]or[m^3]
MANTLE.PassDownwellingVolume            = sum(sum(GRID.cellVolume(MANTLE.passiveDownwelling(:,:,1:end-1)==1)));  %[nd] or [m^2]or[m^3]
MANTLE.PassUpwellingVolPerc             = 100 *MANTLE.PassUpwellingVolume /MANTLE.UpwellingVolume;               %in [% of total upwelling]
MANTLE.PassDownwellingVolPerc           = 100 *MANTLE.PassDownwellingVolume /MANTLE.DownwellingVolume;           %in [% of total downwelling]

%% DISPLAY INFORMATION
disp('   Mantle Upwelling')
disp('     Volume')
disp(['     ',char(183),' total                 = ',num2str(MANTLE.UpwellingVolume,3),' ',GRID.VolDim,...
    ' (',num2str(MANTLE.UpwellingVolPerc,2),' %vol)'])
disp(['     ',char(183),' active                = ',num2str(MANTLE.ActUpwellingVolume,3),' ',GRID.VolDim,...
    ' (',num2str(MANTLE.ActUpwellingVolPerc,2),' %)'])
%     if MANTLE.numHotPlumes==0
%         disp('   No Active Hot Plume');
%     elseif MANTLE.numHotPlumes==1
%         disp('   1 Active Hot Plume:');
%     else
%         disp(['   ',num2str(MANTLE.numHotPlumes),' Active Hot Plumes:']);
%     end
disp(['     ',char(183),' passive               = ',num2str(MANTLE.PassUpwellingVolume,3),' ',GRID.VolDim,...
    ' (',num2str(MANTLE.PassUpwellingVolPerc,2),' %)'])

if MANTLE.plumeHotNumberLM>0
    disp('     Hot-plume mobility')
    if MANTLE.plumeHotNumberUM>0
        if MANTLE.plumeHotNumberUM>1; pluralS = 's'; else; pluralS = ''; end
        disp(['     ',char(183),' upper mantle          = ',num2str(MANTLE.plumeHotVHminUM,2),' ',char(10229),' ',num2str(MANTLE.plumeHotVHmeanUM,2),...
            ' ',char(10230),' ',num2str(MANTLE.plumeHotVHmaxUM,2),' ',SETUP.vDim,...
            ' (',num2str(MANTLE.plumeHotNumberUM,1),' plume',pluralS,' at ',num2str(depthLevelSlices(1),4),' ',GRID.Zdim,' depth)'])
    end
    if MANTLE.plumeHotNumberMM>0
        if MANTLE.plumeHotNumberMM>1; pluralS = 's'; else; pluralS = ''; end
        disp(['     ',char(183),' mid mantle            = ',num2str(MANTLE.plumeHotVHminMM,2),' ',char(10229),' ',num2str(MANTLE.plumeHotVHmeanMM,2),...
            ' ',char(10230),' ',num2str(MANTLE.plumeHotVHmaxMM,2),' ',SETUP.vDim,...
            ' (',num2str(MANTLE.plumeHotNumberMM,1),' plume',pluralS,' at ',num2str(depthLevelSlices(2),4),' ',GRID.Zdim,' depth)'])
    end
    if MANTLE.plumeHotNumberLM>0
        if MANTLE.plumeHotNumberLM>1; pluralS = 's'; else; pluralS = ''; end
        disp(['     ',char(183),' lower mantle          = ',num2str(MANTLE.plumeHotVHminLM,2),' ',char(10229),' ',num2str(MANTLE.plumeHotVHmeanLM,2),...
            ' ',char(10230),' ',num2str(MANTLE.plumeHotVHmaxLM,2),' ',SETUP.vDim,...
            ' (',num2str(MANTLE.plumeHotNumberLM,1),' plume',pluralS,' at ',num2str(depthLevelSlices(3),4),' ',GRID.Zdim,' depth)'])
    end
end

disp('   Mantle Downwelling')
disp('     Volume')
disp(['     ',char(183),' total                 = ',num2str(MANTLE.DownwellingVolume,3),' ',GRID.VolDim,...
    ' (',num2str(MANTLE.DownwellingVolPerc,2),' %vol)'])
disp(['     ',char(183),' active                = ',num2str(MANTLE.ActDownwellingVolume,3),' ',GRID.VolDim,...
    ' (',num2str(MANTLE.ActDownwellingVolPerc,2),' %)'])
%     if MANTLE.numColdPlumes==0
%         disp('   No Active Cold Plume');
%     elseif MANTLE.numColdPlumes==1
%         disp('   1 Active Cold Plume:');
%     else
%         disp(['   ',num2str(MANTLE.numColdPlumes),' Active Cold Plumes:']);
%     end
disp(['     ',char(183),' passive               = ',num2str(MANTLE.PassDownwellingVolume,3),' ',GRID.VolDim,...
    ' (',num2str(MANTLE.PassDownwellingVolPerc,2),' %)'])

if MANTLE.plumeColdNumberLM>0
    disp('     Cold-plume mobility')
    if MANTLE.plumeColdNumberUM>0
        if MANTLE.plumeColdNumberUM>1; pluralS = 's'; else; pluralS = ''; end
        disp(['     ',char(183),' upper mantle          = ',num2str(MANTLE.plumeColdVHminUM,2),' ',char(10229),' ',num2str(MANTLE.plumeColdVHmeanUM,2),...
            ' ',char(10230),' ',num2str(MANTLE.plumeColdVHmaxUM,2),' ',SETUP.vDim,...
            ' (',num2str(MANTLE.plumeColdNumberUM,1),' plume',pluralS,' at ',num2str(depthLevelSlices(1),4),' ',GRID.Zdim,' depth)'])
    end
    if MANTLE.plumeColdNumberMM>0
        if MANTLE.plumeColdNumberMM>1; pluralS = 's'; else; pluralS = ''; end
        disp(['     ',char(183),' mid mantle            = ',num2str(MANTLE.plumeColdVHminMM,2),' ',char(10229),' ',num2str(MANTLE.plumeColdVHmeanMM,2),...
            ' ',char(10230),' ',num2str(MANTLE.plumeColdVHmaxMM,2),' ',SETUP.vDim,...
            ' (',num2str(MANTLE.plumeColdNumberMM,1),' plume',pluralS,' at ',num2str(depthLevelSlices(2),4),' ',GRID.Zdim,' depth)'])
    end
    if MANTLE.plumeColdNumberLM>0
        if MANTLE.plumeColdNumberLM>1; pluralS = 's'; else; pluralS = ''; end
        disp(['     ',char(183),' lower mantle          = ',num2str(MANTLE.plumeColdVHminLM,2),' ',char(10229),' ',num2str(MANTLE.plumeColdVHmeanLM,2),...
            ' ',char(10230),' ',num2str(MANTLE.plumeColdVHmaxLM,2),' ',SETUP.vDim,...
            ' (',num2str(MANTLE.plumeColdNumberLM,1),' plume',pluralS,' at ',num2str(depthLevelSlices(3),4),' ',GRID.Zdim,' depth)'])
    end
end

%% PLOTTING PLUMES SEPARATELY
if MD.plotPLUMES && strcmp(GRID.Dim,'3-D')
    figure(22),clf
    
    x = 1:size(Plumes3D,1);
    y = 1:size(Plumes3D,2);
    z = 1:size(Plumes3D,3);
    [x3d,y3d,z3d] = meshgrid(y,x,z);
    
    phot = patch(isosurface(x3d,y3d,z3d,plumesHot,+0.95)); %HOT
    isonormals(x3d,y3d,z3d,plumesHot,phot)
    set(phot,'FaceColor','red','EdgeColor','none');
    view(3);
    camlight
    lighting phong  %gouraud
    
    hold on
    pcold = patch(isosurface(x3d,y3d,z3d,plumesCold,+0.95)); %COLD
    isonormals(x3d,y3d,z3d,plumesCold,pcold)
    set(pcold,'FaceColor','blue','EdgeColor','none');
    view(3);
    axis([0 max(max(max(x3d))) 0 max(max(max(y3d))) 0 max(max(max(z3d)))])
    camlight
    lighting phong  %gouraud
    
    title('after applying criterion')
    xlabel('x'); ylabel('y'); zlabel('z');
    axis equal
    box on
    grid on
    
    figure(23),clf
    isosurface(Plumes3D,+0.95,'noshare') %HOT
    hold on
    isosurface(Plumes3D,-0.95,'noshare') %COLD
    
    title('original')
    xlabel('x'); ylabel('y'); zlabel('z');
    axis equal
    axis([0 max(max(max(x3d))) 0 max(max(max(y3d))) 0 max(max(max(z3d)))])
    box on
    grid on
    
    figure(1)  %go back to figure(1)
end


%% FUNCTION OUTPUT
MANTLE.upWelling    = upWelling;    %1 for upwelling, 0 else
MANTLE.downWelling  = downWelling;  %1 for downwelling, 0 else
MANTLE.plumesHot  	= plumesHot;    %1 for hot plumes, 0 else
MANTLE.plumesCold 	= plumesCold;   %1 for cold plumes, 0 else
% MANTLE.numHotPlumes               %num
% MANTLE.numColdPlumes              %num
% MANTLE.UpwellingVolume            %[nd] or [m^2]or[m^3]
% MANTLE.DownwellingVolume          %[nd] or [m^2]or[m^3]
% MANTLE.UpwellingVolPerc           %in [% of model domain]
% MANTLE.DownwellingVolPerc         %in [% of model domain]

% MANTLE.activeUpwelling            %1 for active upwelling
% MANTLE.activeDownwelling        	%1 for active downwelling
% MANTLE.numActUpwelling           	%num
% MANTLE.numActDownwelling          %num
% MANTLE.ActUpwellingVolume      	%[nd] or [m^2]or[m^3]
% MANTLE.ActDownwellingVolume      	%[nd] or [m^2]or[m^3]
% MANTLE.ActUpwellingVolPerc    	%in [% of total upwelling]
% MANTLE.ActDownwellingVolPerc     	%in [% of total downwelling]

% MANTLE.passiveUpwelling           %1 for passive upwelling
% MANTLE.passiveDownwelling        	%1 for passive downwelling
% MANTLE.numPassUpwelling           %num
% MANTLE.numPassDownwelling         %num
% MANTLE.PassUpwellingVolume      	%[nd] or [m^2]or[m^3]
% MANTLE.PassDownwellingVolume      %[nd] or [m^2]or[m^3]
% MANTLE.PassUpwellingVolPerc    	%in [% of total upwelling]
% MANTLE.PassDownwellingVolPerc     %in [% of total downwelling]

if strcmp(GRID.Type,'yinyang')
    %add here......
end






















